# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.11] - 2020-08-22

- Conception!

[Unreleased]: https://https://github.com/camlab-bioml/astir/kieranrcampbell/astir/compare/v0.0.11...HEAD
[0.0.11]: https://https://github.com/camlab-bioml/astir/kieranrcampbell/astir/releases/tag/v0.0.11
